@@ -13,7 +13,7 @@ class TestContentProcessorRDoc < Test::Unit::TestCase
     node = Webgen::Node.new(root, 'test', 'test')
     context = Webgen::Context.new(:content => "* hello",
                                                     :chain => [node])
-    assert_equal("<ul>\n<li>hello\n\n</li>\n</ul>\n", obj.call(context).content)
+    assert_equal("<ul>\n<li><p>\nhello\n</p>\n</li>\n</ul>\n", obj.call(context).content)
 
     def obj.require(lib); raise LoadError; end
     assert_raise(Webgen::LoadError) { obj.call(context) }
